@@ -4,7 +4,7 @@ from drf_stripe.stripe_api.products import stripe_api_update_products_prices
 
 
 class Command(BaseCommand):
-    help = "Import Service/Feature types"
+    help = "Import Service/Feature types from Stripe"
 
     def add_arguments(self, parser):
         pass
